@@ -272,9 +272,22 @@ int __connman_element_count(struct connman_element *element,
 	return data.count;
 }
 
+static struct connman_network *__connman_element_get_network(struct connman_element *element)
+{
+	if (element->type == CONNMAN_ELEMENT_TYPE_NETWORK &&
+						element->network != NULL)
+		return element->network;
+
+	if (element->parent == NULL)
+		return NULL;
+
+	return __connman_element_get_network(element->parent);
+}
+
 struct connman_service *__connman_element_get_service(struct connman_element *element)
 {
 	struct connman_service *service;
+	struct connman_network *network;
 	struct connman_device *device;
 	enum connman_device_type type;
 
@@ -287,8 +300,6 @@ struct connman_service *__connman_element_get_service(struct connman_element *el
 	switch (type) {
 	case CONNMAN_DEVICE_TYPE_UNKNOWN:
 	case CONNMAN_DEVICE_TYPE_VENDOR:
-	case CONNMAN_DEVICE_TYPE_WIFI:
-	case CONNMAN_DEVICE_TYPE_WIMAX:
 	case CONNMAN_DEVICE_TYPE_BLUETOOTH:
 	case CONNMAN_DEVICE_TYPE_GPS:
 	case CONNMAN_DEVICE_TYPE_HSO:
@@ -299,6 +310,13 @@ struct connman_service *__connman_element_get_service(struct connman_element *el
 	case CONNMAN_DEVICE_TYPE_ETHERNET:
 		service = __connman_service_lookup_from_device(device);
 		break;
+	case CONNMAN_DEVICE_TYPE_WIFI:
+	case CONNMAN_DEVICE_TYPE_WIMAX:
+		network = __connman_element_get_network(element);
+		if (network == NULL)
+			return NULL;
+		service = __connman_service_lookup_from_network(network);
+		break;
 	}
 
 	return service;
@@ -1294,6 +1312,8 @@ int connman_element_set_enabled(struct connman_element *element,
 void connman_element_set_error(struct connman_element *element,
 					enum connman_element_error error)
 {
+	struct connman_service *service;
+
 	DBG("element %p error %d", element, error);
 
 	if (element->type == CONNMAN_ELEMENT_TYPE_ROOT)
@@ -1304,6 +1324,10 @@ void connman_element_set_error(struct connman_element *element,
 
 	if (element->driver && element->driver->change)
 		element->driver->change(element);
+
+	service = __connman_element_get_service(element);
+	__connman_service_indicate_state(service,
+					CONNMAN_SERVICE_STATE_FAILURE);
 }
 
 int __connman_element_init(DBusConnection *conn, const char *device,
